================
mhmpy Quickstart
================

mhmpy: a python API for the mesoscale Hydrological Model.


Installation
============

.. code-block:: none

    pip install mhmpy


Further Information
===================

Requirements
============

License
=======

`MIT <https://github.com/MuellerSeb/mhmpy/blob/master/LICENSE>`_ © 2019
